@@ -87,7 +87,7 @@ pub trait IntoAngle<To>
 }
 
 /// Base functionality for all angle types.
-pub trait Angle: Clone {
+pub trait Angle: Clone + FromAngle<Self> {
     /// Internal type storing the angle value.
     type Scalar: Float;
 
@@ -126,6 +126,18 @@ pub trait Angle: Clone {
     /// Compute the arctangent of a value, using information from
     /// the numerator and denominator in order to increase the domain.
     fn atan2(x: Self::Scalar, y: Self::Scalar) -> Self;
+
+    /// Return half of a full rotation in some unit.
+    fn half_turn() -> Self;
+    /// Return quarter of a full rotation in some unit.
+    fn quarter_turn() -> Self;
+
+    /// Return the inverse of an angle.
+    ///
+    /// The inverse is equivalent to adding half a rotation
+    /// or inverting the unit vector pointing from the origin along the
+    /// angle.
+    fn invert(self) -> Self;
 }
 
 /// A trait for linear interpolation between angles.
@@ -199,6 +211,16 @@ macro_rules! impl_angle {
             fn atan2(y: T, x: T) -> $Struct<T> {
                 $Struct::from_angle(Rad(y.atan2(x)))
             }
+
+            fn half_turn() -> Self {
+                $Struct(cast::<_, Self::Scalar>(0.5).unwrap() * Self::period())
+            }
+            fn quarter_turn() -> Self {
+                $Struct(cast::<_, Self::Scalar>(0.25).unwrap() * Self::period())
+            }
+            fn invert(self) -> Self {
+                self + Self::half_turn()
+            }
         }
 
         impl<T: Float> Interpolate for $Struct<T> {
@@ -573,4 +595,18 @@ mod test {
         assert_relative_eq!(Turns(0.50).interpolate(&Deg(30.0), 0.25), 
                             Turns(0.39583333333), epsilon=1e-6);
     }
+
+    #[test]
+    fn test_constants() {
+        assert_ulps_eq!(Deg::half_turn(), Deg(180.0));
+        assert_ulps_eq!(Deg::quarter_turn(), Deg(90.0));
+        assert_ulps_eq!(Rad::half_turn(), Rad(consts::PI));
+    }
+
+    #[test]
+    fn test_invert() {
+        assert_ulps_eq!(Deg(0.0).invert(), Deg(180.0));
+        assert_ulps_eq!(Deg(180.0).invert().normalize(), Deg(0.0));
+        assert_ulps_eq!(Deg(80.0).invert(), Deg(260.0));
+    }
 }
